SWDEV-448163 - Fix Doxygen warnings

Change-Id: If72e312461a72920b6a482009c9aef4cf92f2e1b


[ROCm/hip-tests commit: 6c23e25c86]
This commit is contained in:
Branislav Brzak
2024-03-22 11:17:00 +01:00
committed by Branislav Brzak
parent 49a7085d38
commit 35c7d3e1c6
366 changed files with 1919 additions and 89 deletions
@@ -53,4 +53,9 @@ class HipEventCreateBenchmark : public Benchmark<HipEventCreateBenchmark> {
TEST_CASE("Performance_hipEventCreate") {
HipEventCreateBenchmark benchmark;
benchmark.Run();
}
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -80,4 +80,9 @@ TEST_CASE("Performance_hipEventCreateWithFlags") {
hipEventDefault, hipEventBlockingSync,
hipEventDisableTiming /*, hipEventInterprocess disabled until fixed (EXSWHTEC-25) */);
RunBenchmark(flag);
}
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -76,4 +76,9 @@ TEST_CASE("Performance_hipMemset") {
const auto allocation_type = GENERATE(LinearAllocs::hipMalloc, LinearAllocs::hipHostMalloc,
LinearAllocs::hipMallocManaged);
RunBenchmark(allocation_type, size);
}
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -70,3 +70,8 @@ TEST_CASE("Performance_hipMemset2D") {
const auto width = GENERATE(4_KB, 4_MB, 16_MB);
RunBenchmark(width, 32);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -73,3 +73,8 @@ TEST_CASE("Performance_hipMemset2DAsync") {
const auto width = GENERATE(4_KB, 4_MB, 16_MB);
RunBenchmark(width, 32);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -71,3 +71,8 @@ TEST_CASE("Performance_hipMemset3D") {
const auto width = GENERATE(4_KB, 4_MB, 16_MB);
RunBenchmark(width, 16, 4);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -73,3 +73,8 @@ TEST_CASE("Performance_hipMemset3DAsync") {
const auto width = GENERATE(4_KB, 4_MB, 16_MB);
RunBenchmark(width, 16, 4);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -79,3 +79,8 @@ TEST_CASE("Performance_hipMemsetAsync") {
LinearAllocs::hipMallocManaged);
RunBenchmark(allocation_type, size);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -78,3 +78,8 @@ TEST_CASE("Performance_hipMemsetD16") {
LinearAllocs::hipMallocManaged);
RunBenchmark(allocation_type, size);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -80,3 +80,8 @@ TEST_CASE("Performance_hipMemsetD16Async") {
LinearAllocs::hipMallocManaged);
RunBenchmark(allocation_type, size);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -78,3 +78,8 @@ TEST_CASE("Performance_hipMemsetD32") {
LinearAllocs::hipMallocManaged);
RunBenchmark(allocation_type, size);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -80,3 +80,8 @@ TEST_CASE("Performance_hipMemsetD32Async") {
LinearAllocs::hipMallocManaged);
RunBenchmark(allocation_type, size);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -78,3 +78,8 @@ TEST_CASE("Performance_hipMemsetD8") {
LinearAllocs::hipMallocManaged);
RunBenchmark(allocation_type, size);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -80,3 +80,8 @@ TEST_CASE("Performance_hipMemsetD8Async") {
LinearAllocs::hipMallocManaged);
RunBenchmark(allocation_type, size);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -63,3 +63,8 @@ static void RunBenchmark() {
TEST_CASE("Performance_hipExtStreamCreateWithCUMask") {
RunBenchmark();
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -65,3 +65,8 @@ static void RunBenchmark() {
TEST_CASE("Performance_hipExtStreamGetCUMask") {
RunBenchmark();
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -67,3 +67,8 @@ TEST_CASE("Performance_hipFreeAsync") {
size_t array_size = GENERATE(4_KB, 4_MB, 16_MB);
RunBenchmark(array_size);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -66,3 +66,8 @@ TEST_CASE("Performance_hipMallocAsync") {
size_t array_size = GENERATE(4_KB, 4_MB, 16_MB);
RunBenchmark(array_size);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -80,3 +80,8 @@ TEST_CASE("Performance_hipMallocFromPoolAsync") {
size_t array_size = GENERATE(4_KB, 4_MB, 16_MB);
RunBenchmark(array_size);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -69,3 +69,8 @@ TEST_CASE("Performance_hipMemPoolCreate") {
}
RunBenchmark();
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -68,3 +68,8 @@ TEST_CASE("Performance_hipMemPoolDestroy") {
}
RunBenchmark();
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -82,3 +82,8 @@ TEST_CASE("Performance_hipMemPoolExportPointer") {
size_t array_size = GENERATE(4_KB, 4_MB, 16_MB);
RunBenchmark(array_size);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -72,3 +72,8 @@ TEST_CASE("Performance_hipMemPoolExportToShareableHandle") {
}
RunBenchmark();
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -74,3 +74,8 @@ TEST_CASE("Performance_hipMemPoolGetAccess") {
}
RunBenchmark();
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -81,3 +81,8 @@ TEST_CASE("Performance_hipMemPoolGetAttribute") {
hipMemPoolReuseAllowInternalDependencies);
RunBenchmark(attribute);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -78,3 +78,8 @@ TEST_CASE("Performance_hipMemPoolImportFromShareableHandle") {
}
RunBenchmark();
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -85,3 +85,8 @@ TEST_CASE("Performance_hipMemPoolImportPointer") {
size_t array_size = GENERATE(4_KB, 4_MB, 16_MB);
RunBenchmark(array_size);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -77,3 +77,8 @@ TEST_CASE("Performance_hipMemPoolSetAccess") {
}
RunBenchmark();
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -81,3 +81,8 @@ TEST_CASE("Performance_hipMemPoolSetAttribute") {
hipMemPoolReuseAllowInternalDependencies);
RunBenchmark(attribute);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -75,3 +75,8 @@ TEST_CASE("Performance_hipMemPoolTrimTo") {
size_t min_bytes_to_hold = GENERATE(4_KB, 4_MB, 16_MB);
RunBenchmark(min_bytes_to_hold);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -59,3 +59,8 @@ static void RunBenchmark() {
TEST_CASE("Performance_hipStreamAddCallback") {
RunBenchmark();
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -267,3 +267,8 @@ TEST_CASE("Performance_hipStreamSynchronize") {
HipStreamSynchronizeBenchmark benchmark;
benchmark.Run();
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -73,3 +73,8 @@ TEST_CASE("Performance_hipStreamGetFlags") {
unsigned int expected_flag = GENERATE(hipStreamDefault, hipStreamNonBlocking);
RunBenchmark(expected_flag);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -71,4 +71,9 @@ static void RunBenchmark(Streams stream_type) {
TEST_CASE("Performance_hipStreamGetPriority") {
Streams stream_type = GENERATE(Streams::nullstream, Streams::created);
RunBenchmark(stream_type);
}
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -78,3 +78,8 @@ TEST_CASE("Performance_hipStreamWaitEvent") {
Streams stream_type = GENERATE(Streams::nullstream, Streams::created);
RunBenchmark(stream_type);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -170,3 +170,8 @@ TEST_CASE("Performance_hipStreamWaitValue64") {
hipStreamWaitValueNor);
RunBenchmark<StreamWaitValue64Benchmark>(array_size, flag);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -121,3 +121,8 @@ TEST_CASE("Performance_hipStreamWriteValue64") {
size_t array_size = GENERATE(4_KB, 4_MB, 16_MB);
RunBenchmark<StreamWriteValue64Benchmark>(array_size);
}
/**
* End doxygen group PerformanceTest.
* @}
*/
@@ -365,3 +365,8 @@ TEST_CASE("Perf_hipPerfDotProduct") {
HIP_CHECK(hipFree(workspace));
}
}
/**
* End doxygen group perfComputeTest.
* @}
*/
@@ -657,3 +657,8 @@ TEST_CASE("Perf_hipPerfMandelbrot") {
mandelbrotCompute.printResults();
}
}
/**
* End doxygen group perfComputeTest.
* @}
*/
@@ -194,3 +194,8 @@ TEST_CASE("Perf_hipPerfDispatchSpeed") {
}
HIP_CHECK(hipFree(srcBuffer));
}
/**
* End doxygen group perfDispatchTest.
* @}
*/
@@ -240,3 +240,8 @@ TEST_CASE("Perf_hipPerfBufferCopyRectSpeed_test") {
REQUIRE(true == hipPerfBufferCopyRectSpeed_test(1));
}
}
/**
* End doxygen group perfMemoryTest.
* @}
*/
@@ -256,3 +256,8 @@ TEST_CASE("Perf_hipPerfBufferCopySpeed_test") {
REQUIRE(true == hipPerfBufferCopySpeed_test(1));
}
}
/**
* End doxygen group perfMemoryTest.
* @}
*/
@@ -396,4 +396,9 @@ TEST_CASE("Perf_PerfBufferCopySpeedAll2One_test - kernel copy - remotes to local
*/
TEST_CASE("Perf_PerfBufferCopySpeedOne2All_test - kernel copy - local to remotes") {
testCopyPerf(true, true, true);
}
}
/**
* End doxygen group perfMemoryTest.
* @}
*/
@@ -544,4 +544,9 @@ TEST_CASE("Perf_hipTestP2PBiDirKernelCopy_test") {
*/
TEST_CASE("Perf_hipCheckP2PSupport") {
checkP2PSupport();
}
}
/**
* End doxygen group perfMemoryTest.
* @}
*/
@@ -152,3 +152,8 @@ TEST_CASE("Perf_hipPerfDevMemReadSpeed_test") {
REQUIRE(true == hipPerfDevMemReadSpeed_test());
}
}
/**
* End doxygen group perfMemoryTest.
* @}
*/
@@ -145,3 +145,8 @@ TEST_CASE("Perf_hipPerfDevMemWriteSpeed_test") {
REQUIRE(true == hipPerfDevMemWriteSpeed_test());
}
}
/**
* End doxygen group perfMemoryTest.
* @}
*/
@@ -188,3 +188,8 @@ TEST_CASE("Perf_hipPerfHostNumaAlloc_test") {
hipHostMallocMapped | hipHostMallocNumaUser,
"Testing hipHostMallocMapped | hipHostMallocNumaUser......."));
}
/**
* End doxygen group perfMemoryTest.
* @}
*/
@@ -543,3 +543,8 @@ TEST_CASE("Perf_hipPerfMemFill_test") {
REQUIRE(true == hipPerfMemFillDouble.open(0));
REQUIRE(true == hipPerfMemFillDouble.run());
}
/**
* End doxygen group perfMemoryTest.
* @}
*/
@@ -142,3 +142,8 @@ TEST_CASE("Perf_hipPerfMemMallocCpyFree_test") {
REQUIRE(true == hipPerfMemMallocCpyFree_test());
}
}
/**
* End doxygen group perfMemoryTest.
* @}
*/
@@ -254,3 +254,8 @@ TEST_CASE("Perf_hipPerfMemcpy_test") {
}
}
}
/**
* End doxygen group perfMemoryTest.
* @}
*/
@@ -429,3 +429,8 @@ TEST_CASE("Perf_hipPerfMemset_test") {
async = true;
}
}
/**
* End doxygen group perfMemoryTest.
* @}
*/
@@ -307,3 +307,8 @@ TEST_CASE("Perf_hipPerfSampleRate_test") {
sampleTypes.run(testCase);
}
}
/**
* End doxygen group perfMemoryTest.
* @}
*/
@@ -260,3 +260,8 @@ TEST_CASE("Perf_hipPerfSharedMemReadSpeed_test") {
REQUIRE(true == hipPerfSharedMemReadSpeed_test());
}
}
/**
* End doxygen group perfMemoryTest.
* @}
*/
@@ -267,3 +267,8 @@ TEST_CASE("Perf_hipPerfDeviceConcurrency") {
// Time for kernel on all available devices
REQUIRE(true == deviceConcurrency.run(++testCase, nGpu));
}
/**
* End doxygen group perfStreamTest.
* @}
*/
@@ -413,3 +413,8 @@ TEST_CASE("Perf_hipPerfStreamConcurrency") {
REQUIRE(true == streamConcurrency.run(testCase, deviceId));
}
}
/**
* End doxygen group perfComputeTest.
* @}
*/
@@ -144,3 +144,8 @@ TEST_CASE("Perf_hipPerfStreamCreateCopyDestroy") {
REQUIRE(true == streamCCD.run(testCase));
}
}
/**
* End doxygen group perfStreamTest.
* @}
*/
@@ -110,3 +110,8 @@ TEST_CASE("Stress_hipHostRegister_Oversubscription") {
HIP_CHECK(hipHostUnregister(A));
free(A);
}
/**
* End doxygen group MemoryTest.
* @}
*/
@@ -122,3 +122,8 @@ TEST_CASE("Unit_Assert_Positive_Basic_KernelFail") {
REQUIRE(abort_raised_flag == 0);
#endif
}
/**
* End doxygen group DeviceLanguageTest.
* @}
*/
@@ -86,3 +86,8 @@ TEST_CASE("Unit_StaticAssert_Positive_Basic_RTC") { StaticAssertWrapper(kStaticA
* - HIP_VERSION >= 5.2
*/
TEST_CASE("Unit_StaticAssert_Negative_Basic_RTC") { StaticAssertWrapper(kStaticAssert_Negative); }
/**
* End doxygen group DeviceLanguageTest.
* @}
*/
@@ -126,4 +126,9 @@ TEMPLATE_TEST_CASE("Unit___hip_atomic_compare_exchange_strong_Positive_Workgroup
__HIP_MEMORY_SCOPE_WORKGROUP>(warp_size, cache_line_size);
}
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -133,4 +133,9 @@ TEMPLATE_TEST_CASE("Unit___hip_atomic_exchange_Positive_Workgroup", "", int, uns
cache_line_size);
}
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -129,4 +129,9 @@ TEMPLATE_TEST_CASE("Unit___hip_atomic_fetch_add_Positive_Workgroup", "", int, un
__HIP_MEMORY_SCOPE_WORKGROUP>(warp_size, cache_line_size);
}
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -185,3 +185,8 @@ TEMPLATE_TEST_CASE("Unit___hip_atomic_fetch_and_Positive_Workgroup_Scattered_Add
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -184,4 +184,9 @@ TEMPLATE_TEST_CASE("Unit___hip_atomic_fetch_max_Positive_Workgroup_Scattered_Add
cache_line_size);
}
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -184,4 +184,9 @@ TEMPLATE_TEST_CASE("Unit___hip_atomic_fetch_min_Positive_Workgroup_Scattered_Add
cache_line_size);
}
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -185,3 +185,8 @@ TEMPLATE_TEST_CASE("Unit___hip_atomic_fetch_or_Positive_Workgroup_Scattered_Addr
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -185,3 +185,8 @@ TEMPLATE_TEST_CASE("Unit___hip_atomic_fetch_xor_Positive_Workgroup_Scattered_Add
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -165,3 +165,8 @@ TEST_CASE("Unit_atomicAdd_Negative_Parameters_RTC") {
HIPRTC_CHECK_ERROR(result, HIPRTC_ERROR_COMPILATION);
REQUIRE(error_count == expected_error_count);
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -175,3 +175,8 @@ TEMPLATE_TEST_CASE("Unit_atomicAdd_system_Positive_Host_And_Peer_GPUs", "", int,
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -220,3 +220,8 @@ TEST_CASE("Unit_atomicAnd_Negative_Parameters_RTC") {
HIPRTC_CHECK_ERROR(result, HIPRTC_ERROR_COMPILATION);
REQUIRE(error_count == expected_error_count);
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -107,3 +107,8 @@ TEMPLATE_TEST_CASE("Unit_atomicAnd_system_Positive_Peer_GPUs_Scattered_Addresses
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -170,3 +170,8 @@ TEST_CASE("Unit_atomicCAS_Negative_Parameters_RTC") {
HIPRTC_CHECK_ERROR(result, HIPRTC_ERROR_COMPILATION);
REQUIRE(error_count == expected_error_count);
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -183,3 +183,8 @@ TEMPLATE_TEST_CASE("Unit_atomicCAS_system_Positive_Host_And_Peer_GPUs", "", int,
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -161,4 +161,9 @@ TEST_CASE("Unit_atomicDec_Negative_Parameters_RTC") {
HIPRTC_CHECK(hiprtcDestroyProgram(&program));
HIPRTC_CHECK_ERROR(result, HIPRTC_ERROR_COMPILATION);
REQUIRE(error_count == expected_error_count);
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -211,3 +211,8 @@ TEST_CASE("Unit_atomicExch_Negative_Parameters_RTC") {
HIPRTC_CHECK_ERROR(result, HIPRTC_ERROR_COMPILATION);
REQUIRE(error_count == expected_error_count);
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -233,3 +233,8 @@ TEST_CASE("Unit_atomicExch_system_Negative_Parameters_RTC") {
HIPRTC_CHECK_ERROR(result, HIPRTC_ERROR_COMPILATION);
REQUIRE(error_count == expected_error_count);
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -161,4 +161,9 @@ TEST_CASE("Unit_atomicInc_Negative_Parameters_RTC") {
HIPRTC_CHECK(hiprtcDestroyProgram(&program));
HIPRTC_CHECK_ERROR(result, HIPRTC_ERROR_COMPILATION);
REQUIRE(error_count == expected_error_count);
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -220,3 +220,8 @@ TEST_CASE("Unit_atomicMax_Negative_Parameters_RTC") {
HIPRTC_CHECK_ERROR(result, HIPRTC_ERROR_COMPILATION);
REQUIRE(error_count == expected_error_count);
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -122,3 +122,8 @@ TEMPLATE_TEST_CASE("Unit_atomicMax_system_Positive_Peer_GPUs_Scattered_Addresses
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -220,3 +220,8 @@ TEST_CASE("Unit_atomicMin_Negative_Parameters_RTC") {
HIPRTC_CHECK_ERROR(result, HIPRTC_ERROR_COMPILATION);
REQUIRE(error_count == expected_error_count);
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -122,3 +122,8 @@ TEMPLATE_TEST_CASE("Unit_atomicMin_system_Positive_Peer_GPUs_Scattered_Addresses
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -220,3 +220,8 @@ TEST_CASE("Unit_atomicOr_Negative_Parameters_RTC") {
HIPRTC_CHECK_ERROR(result, HIPRTC_ERROR_COMPILATION);
REQUIRE(error_count == expected_error_count);
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -107,3 +107,8 @@ TEMPLATE_TEST_CASE("Unit_atomicOr_system_Positive_Peer_GPUs_Scattered_Addresses"
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -164,4 +164,9 @@ TEST_CASE("Unit_atomicSub_Negative_Parameters_RTC") {
HIPRTC_CHECK(hiprtcDestroyProgram(&program));
HIPRTC_CHECK_ERROR(result, HIPRTC_ERROR_COMPILATION);
REQUIRE(error_count == expected_error_count);
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -175,3 +175,8 @@ TEMPLATE_TEST_CASE("Unit_atomicSub_system_Positive_Host_And_Peer_GPUs", "", int,
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -220,3 +220,8 @@ TEST_CASE("Unit_atomicXor_Negative_Parameters_RTC") {
HIPRTC_CHECK_ERROR(result, HIPRTC_ERROR_COMPILATION);
REQUIRE(error_count == expected_error_count);
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -107,3 +107,8 @@ TEMPLATE_TEST_CASE("Unit_atomicXor_system_Positive_Peer_GPUs_Scattered_Addresses
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -95,3 +95,8 @@ TEST_CASE("Unit_AtomicBuiltins_Negative_Parameters_RTC") {
AtomicBuiltinsRTCWrapper(kBuiltinFetchMax, 5, 2);
AtomicBuiltinsRTCWrapper(kBuiltinFetchMin, 5, 2);
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -121,3 +121,8 @@ TEMPLATE_TEST_CASE("Unit_safeAtomicAdd_Positive_Multi_Kernel", "", float, double
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -173,3 +173,8 @@ TEMPLATE_TEST_CASE("Unit_safeAtomicMax_Positive_Multi_Kernel_Scattered_Addresses
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -173,3 +173,8 @@ TEMPLATE_TEST_CASE("Unit_safeAtomicMin_Positive_Multi_Kernel_Scattered_Addresses
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -122,3 +122,8 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_Positive_Multi_Kernel", "", float, doub
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -173,3 +173,8 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicMax_Positive_Multi_Kernel_Scattered_Address
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -173,3 +173,8 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicMin_Positive_Multi_Kernel_Scattered_Address
}
}
}
/**
* End doxygen group AtomicsTest.
* @}
*/
@@ -77,3 +77,8 @@ TEST_CASE("Unit_hipApiName_Negative_ReservedIds") {
REQUIRE_THAT(hipApiName(std::numeric_limits<uint32_t>::min()), Catch::Equals(kUnknownApi));
REQUIRE_THAT(hipApiName(std::numeric_limits<uint32_t>::max()), Catch::Equals(kUnknownApi));
}
/**
* End doxygen group CallbackTest.
* @}
*/
@@ -110,3 +110,8 @@ TEST_CASE("Unit_hipGetStreamDeviceId_Negative_Parameters") {
StreamGuard stream_guard{Streams::nullstream};
REQUIRE(hipGetStreamDeviceId(stream_guard.stream()) == id);
}
/**
* End doxygen group CallbackTest.
* @}
*/
@@ -69,3 +69,8 @@ TEST_CASE("Unit_hipKernelNameRef_Negative_Parameters") {
hipFunction_t kernel_function{nullptr};
REQUIRE(hipKernelNameRef(kernel_function) == nullptr);
}
/**
* End doxygen group CallbackTest.
* @}
*/
@@ -103,3 +103,8 @@ TEST_CASE("Unit_hipKernelNameRefByPtr_Negative_KernelNullptr") {
REQUIRE(hipKernelNameRefByPtr(kernel_ptr, stream_guard.stream()) == nullptr);
}
}
/**
* End doxygen group CallbackTest.
* @}
*/
@@ -192,3 +192,8 @@ TEST_CASE("Unit_ChannelDescriptor_Positive_16BitFloatingPoint") {
REQUIRE(channel_desc.f == referent_channel_desc.f);
}
#endif
/**
* End doxygen group DeviceLanguageTest.
* @}
*/
@@ -189,3 +189,8 @@ TEST_CASE("Unit_hipWallClock64_Positive_Basic") {
REQUIRE(kernel_time_execution(kernel_wc64, clock_rate, expected_time1, expected_time2));
}
/**
* End doxygen group DeviceLanguageTest.
* @}
*/

Some files were not shown because too many files have changed in this diff Show More